@@ -18,7 +18,7 @@ from cvehound.util import get_spatch_version, get_all_cves, get_cves_metadata
 from cvehound.kbuild import KbuildParser
 from cvehound.config import Config
 
-__VERSION__ = '1.0.2'
+__VERSION__ = '1.0.3'
 
 
 class CVEhound:
@@ -108,7 +108,7 @@ class CVEhound:
             includes.append('--include')
             includes.append(kconfig)
 
-        logging.info('Checking: ' + cve)
+        logging.debug('Checking: ' + cve)
 
         output = ''
         run = None
@@ -167,6 +167,10 @@ class CVEhound:
                     logging.info('MSG: ' + info['cmt_msg'])
                 if 'cwe' in info:
                     logging.info('CWE: ' + info['cwe'])
+                if 'cvss2' in info and 'score' in info['cvss2']:
+                    logging.info('CVSS2: ' + str(info['cvss2']['score']))
+                if 'cvss3' in info and 'score' in info['cvss3']:
+                    logging.info('CVSS3: ' + str(info['cvss3']['score']))
                 if 'fix_date' in info:
                     logging.info('FIX DATE: ' + str(datetime.utcfromtimestamp(info['fix_date'])))
             logging.info('https://www.linuxkernelcves.com/cves/' + cve)
